==> qgis_0.8.0.orig.tar.gz: qgis-0.8.0/src/core/qgsproviderextentcalcevent.cpp <==
/***************************************************************************
      qgsproviderextentcalcevent.cpp  -  Notification that the exact extent
                                         of a layer has been calculated.
                             -------------------
    begin                : Feb 1, 2005
    copyright            : (C) 2005 by Brendan Morley
    email                : morb at ozemail dot com dot au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
/* $Id: qgsproviderextentcalcevent.cpp 4502 2006-01-08 01:18:20Z timlinux $ */

#include "qgsproviderextentcalcevent.h"
//Added by qt3to4:
#include <QCustomEvent>

QgsProviderExtentCalcEvent::QgsProviderExtentCalcEvent( QgsRect* layerExtent )
    : QCustomEvent( QGis::ProviderExtentCalcEvent ),
      le( layerExtent )
{
  // NO-OP
}


QgsRect* QgsProviderExtentCalcEvent::layerExtent() const
{
  return le;
}

==> qgis_1.3.0.tar.gz: qgis-1.3.0/src/core/qgsproviderextentcalcevent.cpp <==
/***************************************************************************
      qgsproviderextentcalcevent.cpp  -  Notification that the exact extent
                                         of a layer has been calculated.
                             -------------------
    begin                : Feb 1, 2005
    copyright            : (C) 2005 by Brendan Morley
    email                : morb at ozemail dot com dot au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
/* $Id: qgsproviderextentcalcevent.cpp 9605 2008-11-09 00:14:12Z timlinux $ */

#include "qgsproviderextentcalcevent.h"
#include "qgis.h"

QgsProviderExtentCalcEvent::QgsProviderExtentCalcEvent( QgsRectangle* layerExtent )
    : QEvent( static_cast<QEvent::Type>( QGis::ProviderExtentCalcEvent ) ),
    le( layerExtent )
{
  // NO-OP
}


QgsRectangle* QgsProviderExtentCalcEvent::layerExtent() const
{
  return le;
}
